@@ -27,11 +27,11 @@ import pathlib
 import sys
 from typing import TYPE_CHECKING, List, Set, Type
 
-from rich.console import Console
 from rich.markdown import Markdown
 
 from ansiblelint import cli, formatters
-from ansiblelint.generate_docs import rules_as_rst
+from ansiblelint.color import console, console_stderr
+from ansiblelint.generate_docs import rules_as_rich, rules_as_rst
 from ansiblelint.rules import RulesCollection
 from ansiblelint.runner import Runner
 from ansiblelint.utils import get_playbooks_and_roles, get_rules_dirs
@@ -42,7 +42,12 @@ if TYPE_CHECKING:
     from ansiblelint.errors import MatchError
 
 _logger = logging.getLogger(__name__)
-console = Console()
+
+_rule_format_map = {
+    'plain': str,
+    'rich': rules_as_rich,
+    'rst': rules_as_rst
+}
 
 
 def initialize_logger(level: int = 0) -> None:
@@ -79,19 +84,37 @@ def choose_formatter_factory(
     return r
 
 
-def hint_about_skips(matches: List["MatchError"]):
-    """Display information about how to skip found rules."""
+def report_outcome(matches: List["MatchError"], options) -> int:
+    """Display information about how to skip found rules.
+
+    Returns exit code, 2 if errors were found, 0 when only warnings were found.
+    """
+    failure = False
     msg = """\
-You can skip specific rules by adding them to the skip_list section of your configuration file:
+You can skip specific rules or tags by adding them to your configuration file:
 ```yaml
 # .ansible-lint
-skip_list:
+warn_list:  # or 'skip_list' to silence them completely
 """
-    matched_rules = {match.rule.id: match.rule.shortdesc for match in matches}
+
+    matched_rules = {match.rule.id: match.rule for match in matches}
     for id in sorted(matched_rules.keys()):
-        msg += f"  - '{id}'  # {matched_rules[id]}'\n"
+        if {id, *matched_rules[id].tags}.isdisjoint(options.warn_list):
+            msg += f"  - '{id}'  # {matched_rules[id].shortdesc}\n"
+            failure = True
+    for match in matches:
+        if "experimental" in match.rule.tags:
+            msg += "  - experimental  # all rules tagged as experimental\n"
+            break
     msg += "```"
-    console.print(Markdown(msg))
+
+    if matches and not options.quiet:
+        console_stderr.print(Markdown(msg))
+
+    if failure:
+        return 2
+    else:
+        return 0
 
 
 def main() -> int:
@@ -111,8 +134,9 @@ def main() -> int:
     rules = RulesCollection(rulesdirs)
 
     if options.listrules:
-        formatted_rules = rules if options.format == 'plain' else rules_as_rst(rules)
-        print(formatted_rules)
+        console.print(
+            _rule_format_map[options.format](rules),
+            highlight=False)
         return 0
 
     if options.listtags:
@@ -154,8 +178,7 @@ def main() -> int:
             print(formatter.format(match))
 
     if matches:
-        hint_about_skips(matches)
-        return 2
+        return report_outcome(matches, options=options)
     else:
         return 0
 
