@@ -96,8 +96,8 @@ def get_cli_parser() -> argparse.ArgumentParser:
 
     parser.add_argument('-L', dest='listrules', default=False,
                         action='store_true', help="list all the rules")
-    parser.add_argument('-f', dest='format', default='plain',
-                        choices=['plain', 'rst'],
+    parser.add_argument('-f', dest='format', default='rich',
+                        choices=['rich', 'plain', 'rst'],
                         help="Format used rules output, (default: %(default)s)")
     parser.add_argument('-q', dest='quiet',
                         default=False,
@@ -134,6 +134,9 @@ def get_cli_parser() -> argparse.ArgumentParser:
     parser.add_argument('-x', dest='skip_list', default=[], action='append',
                         help="only check rules whose id/tags do not "
                         "match these values")
+    parser.add_argument('-w', dest='warn_list', default=[], action='append',
+                        help="only warn about these rules, unless overridden in "
+                             "config file defaults to 'experimental'")
     parser.add_argument('--nocolor', dest='colored',
                         default=hasattr(sys.stdout, 'isatty') and sys.stdout.isatty(),
                         action='store_false',
@@ -161,42 +164,36 @@ def get_cli_parser() -> argparse.ArgumentParser:
 
 
 def merge_config(file_config, cli_config) -> NamedTuple:
+    bools = (
+        'display_relative_path',
+        'parseable',
+        'parseable_severity',
+        'quiet',
+        'use_default_rules',
+    )
+    # maps lists to their default config values
+    lists_map = {
+        'exclude_paths': [],
+        'rulesdir': [],
+        'skip_list': [],
+        'tags': [],
+        'warn_list': ['experimental'],
+    }
+
     if not file_config:
         return cli_config
 
-    if 'quiet' in file_config:
-        cli_config.quiet = cli_config.quiet or file_config['quiet']
+    for entry in bools:
+        x = getattr(cli_config, entry) or file_config.get(entry, False)
+        setattr(cli_config, entry, x)
 
-    if 'parseable' in file_config:
-        cli_config.parseable = (cli_config.parseable or
-                                file_config['parseable'])
-
-    if 'parseable_severity' in file_config:
-        cli_config.parseable_severity = (cli_config.parseable_severity or
-                                         file_config['parseable_severity'])
-
-    if 'display_relative_path' in file_config:
-        cli_config.display_relative_path = (cli_config.display_relative_path or
-                                            file_config['display_relative_path'])
-
-    if 'use_default_rules' in file_config:
-        cli_config.use_default_rules = (cli_config.use_default_rules or
-                                        file_config['use_default_rules'])
+    for entry, default in lists_map.items():
+        getattr(cli_config, entry).extend(file_config.get(entry, default))
 
     if 'verbosity' in file_config:
         cli_config.verbosity = (cli_config.verbosity +
                                 file_config['verbosity'])
 
-    cli_config.exclude_paths.extend(file_config.get('exclude_paths', []))
-
-    cli_config.rulesdir.extend(file_config.get('rulesdir', []))
-
-    if 'skip_list' in file_config:
-        cli_config.skip_list = cli_config.skip_list + file_config['skip_list']
-
-    if 'tags' in file_config:
-        cli_config.tags = cli_config.tags + file_config['tags']
-
     return cli_config
 
 
