@@ -18,19 +18,23 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from ansiblelint import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule
 
 
 class TaskHasNameRule(AnsibleLintRule):
-    id = 'ANSIBLE0011'
+    id = '502'
     shortdesc = 'All tasks should be named'
-    description = 'All tasks should have a distinct name for readability ' + \
-                  'and for --start-at-task to work'
-    tags = ['readability']
+    description = (
+        'All tasks should have a distinct name for readability '
+        'and for ``--start-at-task`` to work'
+    )
+    severity = 'MEDIUM'
+    tags = ['task', 'readability', 'ANSIBLE0011']
+    version_added = 'historic'
 
     _nameless_tasks = ['meta', 'debug', 'include_role', 'import_role',
                        'include_tasks', 'import_tasks']
 
     def matchtask(self, file, task):
         return (not task.get('name') and
-            task["action"]["__ansible_module__"] not in self._nameless_tasks)
+                task["action"]["__ansible_module__"] not in self._nameless_tasks)
