@@ -45,7 +45,9 @@ from ansible.template import Templar
 from yaml.composer import Composer
 from yaml.representer import RepresenterError
 
-from ansiblelint.constants import ANSIBLE_FAILURE_RC, FileType
+from ansiblelint.constants import (
+    ANSIBLE_FAILURE_RC, CUSTOM_RULESDIR_ENVVAR, DEFAULT_RULESDIR, FileType,
+)
 from ansiblelint.errors import MatchError
 from ansiblelint.file_utils import normpath
 
@@ -217,6 +219,10 @@ def play_children(basedir, item, parent_type, playbook_dir):
 
 
 def _include_children(basedir, k, v, parent_type):
+    # handle special case include_tasks: name=filename.yml
+    if k == 'include_tasks' and isinstance(v, dict) and 'file' in v:
+        v = v['file']
+
     # handle include: filename.yml tags=blah
     (command, args, kwargs) = tokenize("{0}: {1}".format(k, v))
 
@@ -772,7 +778,8 @@ def get_playbooks_and_roles(options=None) -> List[str]:  # noqa: C901
 
 def expand_path_vars(path: str) -> str:
     """Expand the environment or ~ variables in a path string."""
-    path = path.strip()
+    # It may be possible for function to be called with a Path object
+    path = str(path).strip()
     path = os.path.expanduser(path)
     path = os.path.expandvars(path)
     return path
@@ -782,3 +789,20 @@ def expand_paths_vars(paths: List[str]) -> List[str]:
     """Expand the environment or ~ variables in a list."""
     paths = [expand_path_vars(p) for p in paths]
     return paths
+
+
+def get_rules_dirs(rulesdir: List[str], use_default: bool) -> List[str]:
+    """Return a list of rules dirs."""
+    default_ruledirs = [DEFAULT_RULESDIR]
+    default_custom_rulesdir = os.environ.get(
+        CUSTOM_RULESDIR_ENVVAR, os.path.join(DEFAULT_RULESDIR, "custom")
+    )
+    custom_ruledirs = sorted(
+        str(rdir.resolve())
+        for rdir in Path(default_custom_rulesdir).iterdir()
+        if rdir.is_dir() and (rdir / "__init__.py").exists()
+    )
+    if use_default:
+        return rulesdir + custom_ruledirs + default_ruledirs
+
+    return rulesdir or custom_ruledirs + default_ruledirs
